@@ -21,11 +21,13 @@ our %EXPORT_TAGS = (
     qw{
       $AMPERSAND
       $COLON
-      $COLOR
+      $COMMA
       $DOUBLE_COLON
+      $DASH
       $DOT
       $EMPTY
       $EQUALS_SIGN
+      $OCTOTHORP
       $PERIOD
       $QUESTION_MARK
       $SLASH
@@ -41,15 +43,18 @@ our %EXPORT_TAGS = (
   ],
 );
 
-our $VERSION = '1.3.5';
+our $VERSION = '2.0.0';
 
 # chars
 Readonly our $AMPERSAND          => q{&};
 Readonly our $COLON              => q{:};
+Readonly our $COMMA              => q{,};
 Readonly our $DOUBLE_COLON       => q{::};
+Readonly our $DASH               => q{-};
 Readonly our $DOT                => q{.};
 Readonly our $EMPTY              => q{};
 Readonly our $EQUALS_SIGN        => q{=};
+Readonly our $OCTOTHORP          => q{#};
 Readonly our $PERIOD             => q{.};
 Readonly our $QUESTION_MARK      => q{?};
 Readonly our $SLASH              => q{/};
