@@ -3,9 +3,9 @@ package Amazon::API::Signature4;
 use strict;
 use warnings;
 
-use parent qw{ Exporter AWS::Signature4 };
+use parent qw( Exporter AWS::Signature4 );
 
-our $VERSION = '1.3.5';
+our $VERSION = '2.0.0';
 
 our @EXPORT_OK = qw{ parse_service_url };
 
